<?php
namespace Pinpoint\BannerManager\Controller\Adminhtml\Banners;
use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
/**
 * Class Remove
 * @package Pinpoint\BannerManager\Controller\Adminhtml\Banners
 */
class Remove extends Action
{
    /**
     * @var \Magento\Framework\Controller\Result\JsonFactory
     */
    protected $resultJsonFactory;

    /**
     * @var \Pinpoint\BannerManager\Model\Banner
     */
    protected $banner;

    /**
     * @var \Pinpoint\BannerManager\Model\BannerBlock
     */
    protected $bannerBlock;

    /**
     * Get constructor.
     * @param Context $context
     * @param \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory
     */
    public function __construct(
        Context $context,
        \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory,
        \Pinpoint\BannerManager\Model\Banner $banner,
        \Pinpoint\BannerManager\Model\BannerBlock $bannerBlock
    ) {
        parent::__construct($context);

        $this->resultJsonFactory = $resultJsonFactory;
        $this->banner = $banner;
        $this->bannerBlock = $bannerBlock;
    }

    /**
     * Check the permission to run it
     *
     * @return boolean
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('Pinpoint_BannerManager::manage');
    }

    /**
     * @return \Magento\Framework\Controller\Result\Json
     */
    public function execute()
    {
        /** @var \Magento\Framework\Controller\Result\Json $resultPage */
        $resultPage = $this->resultJsonFactory->create();

        $this->banner->load($this->getRequest()->getParam('id'))->delete();

        $blocks = $this->bannerBlock->getCollection()
            ->addFieldToFilter('banner_id', $this->getRequest()->getParam('id'))
            ->load()
        ;

        foreach ($blocks->getItems() as $block) {
            $this->bannerBlock->load($block->getId())->delete();
        }

        return $resultPage->setData(['success' => true, 'location' => $this->getUrl('*/*/bannerslist')]);
    }

    /**
     * @param $key
     * @param $block
     * @return null
     */
    protected function getBlockValue($key, $block)
    {
        foreach ($block as $input) {
            if ($input['name'] == $key) {
                return $input['value'];
            }
        }

        return null;
    }
}
